@@ -12,9 +12,12 @@
 #and to make the grouping function actually work
 #find the best fitting phase  (in hours)
 #cleaned up March 9, 2015 to allow a more natural calling sequence
-"circadian.phase" <- 
-"cosinor" <- 
-function(angle,x=NULL,code=NULL,data = NULL, hours=TRUE,period=24,plot=FALSE,opti=FALSE,na.rm=TRUE) {
+#modifed Jan - April, 2016 to make cleaner code
+
+#Added cosinor.period April 21, 2016 to iteratively fit period as an option 
+
+"cosinor.period" <- 
+function(angle,x=NULL,code=NULL,data = NULL, hours=TRUE,period=seq(23,26,1),plot=FALSE,opti=FALSE,na.rm=TRUE) {
 #first, organize the data in terms of the input
   if(!is.null(data)) {
       if(is.matrix(data)) data <- data.frame(data)
@@ -33,8 +36,96 @@ function(angle,x=NULL,code=NULL,data = NULL, hours=TRUE,period=24,plot=FALSE,opt
                   x <- x[-1]
                  }               
      } 
-if(hours) { angle <- angle*2*pi/period 
-  x <- cbind(angle,x)}  #convert to radians
+xdata <- x   #we need to save this to do iterative fits
+old.angle <- angle
+per <- period 
+fit.period <- list()
+for (i in 1:length(per)) { 
+  period <- per[i]
+if(hours) { angle <- old.angle*2*pi/period 
+  x <- cbind(angle,xdata)}  #convert to radians
+
+nvar <- dim(xdata)[2] -1
+if(is.null(code)) { fit <- cosinor1(angle,x[-1],period=period,opti=opti,na.rm=na.rm)  #if there is a code (i.e., subject id), then do the fits for each separate subject
+m.resp <- mean(x[,1])
+s.resp <- sd(x[,1])} else {
+
+#x <- angle
+fit.list <- by(x,x[code],function(x) cosinor1(angle=x[1],x=x[-c(1,which(colnames(x)==
+   code))],period=period,opti=opti,na.rm=na.rm))  #this is the case if code is specified
+   ncases <- length(fit.list)
+   
+fit <- matrix(unlist(fit.list),nrow=ncases,byrow=TRUE)
+   colnames(fit) <- c(paste(colnames(x)[-c(1,which(colnames(x)==
+   code))], "phase",sep="."),paste(colnames(x)[-c(1,which(colnames(x)==
+   code))], "fit",sep="."),paste(colnames(x)[-c(1,which(colnames(x)==
+   code))], "amp",sep="."),paste(colnames(x)[-c(1,which(colnames(x)==
+   code))], "sd",sep="."),paste(colnames(x)[-c(1,which(colnames(x)==
+   code))], "mean",sep="."),paste(colnames(x)[-c(1,which(colnames(x)==
+   code))], "intercept",sep=".")) 
+   rownames(fit) <- names(fit.list) 
+ }
+
+  fit.period[[i]] <- list(fit)
+ }
+ x <- NA   #just to avoid being told that x is a global 
+ 
+ #now, find for each variable and for each subject, that value of of fit which is maximized, and then what is the 
+ ncols <- 6 * length(x)
+ fit.m <- matrix(unlist(fit.period),nrow=ncases,byrow=FALSE)
+ #the fits are every nvar * 6 elements starting at nvar + 1
+ 
+ maxfit <- per
+ np <- length(per)
+ fits <- cbind(matrix(NA,nrow=ncases,ncol=nvar),fit)
+ for (j in 1:ncases) { #do it for each subject
+     for (i in 1:nvar) {#do it for each variable
+       for (p in 1:np) {#find the fits for all periods
+   #maxfit[p]  <-   fit.m[j,(p-1) * nvar * 6 + nvar+1]
+   maxfit[p] <- fit.period[[p]][[1]][j,i+nvar]
+  } 
+  max.period <- which.max(maxfit)
+
+  fits[j,i] <- per[max.period]
+  fits[j,i+nvar] <- fit.period[[max.period]][[1]][j,i]
+  fits[j,i+2*nvar] <- fit.period[[max.period]][[1]][j,i+nvar]
+  fits[j,i+3*nvar] <- fit.period[[max.period]][[1]][j,i + 2*nvar]
+  fits[j,i+4*nvar] <- fit.period[[max.period]][[1]][j,i+3* nvar]
+  fits[j,i+5*nvar] <- fit.period[[max.period]][[1]][j,i + 4*nvar]
+  fits[j,i+6*nvar] <- fit.period[[max.period]][[1]][j,i+5* nvar]
+  } 
+   }
+    
+return(fits)
+}
+
+#revised 9/15/18 to handle radians correctly and to handle character names for variables
+
+"circadian.phase" <- 
+"cosinor" <- 
+function(angle,x=NULL,code=NULL,data = NULL, hours=TRUE,period=24,plot=FALSE,opti=FALSE,na.rm=TRUE) {
+#first, organize the data in terms of the input
+  if(!is.null(data)) {
+      if(is.matrix(data)) data <- data.frame(data)
+       if(is.character(angle)) angle <- which(colnames(data) == angle)
+       if(is.character(x)) x <- which(colnames(data) ==x)
+     if(!is.null(code)) { if(is.character(code))  codeloc <- which(colnames(data) ==code)
+             
+              x <- data[,c(angle,x,codeloc)] } else {x <- data[,c(angle,x)]}
+               angle <- x[1]
+               x <- x[-1]
+     } else {
+  if (is.null(x) && is.null(code)) {angle <- data.frame(angle)
+                  x <- angle
+                 angle<- angle[,1]
+                 } else {x <- data.frame(x)
+                    x <- cbind(angle,x)
+                  angle <- x[1]
+                  x <- x[-1]
+                 }               
+     } 
+if(hours) { angle <- angle*2*pi/period }   #convert to radians
+  x <- cbind(angle,x) 
 
 nvar <- dim(x)[2]
 if(is.null(code)) { fit <- cosinor1(angle,x[-1],period=period,opti=opti,na.rm=na.rm)  #if there is a code (i.e., subject id), then do the fits for each separate subject
@@ -386,7 +477,7 @@ class(result) <- c("psych","circadian")
 return(result)
 }
 
-print.circadian <- function(x,short=TRUE,digits=2) {
+print_circadian <- function(x,short=TRUE,digits=2) {
     if(!is.null(x$Call)) {cat("Call: ")
                  print(x$Call)}
       	cat("\nCircadian Statistics :\n")
