@@ -109,11 +109,13 @@ if(inherits(x,"formula")) {ps <- fparse(x)   #group was specified, call describe
    	if(fast) {skew <- FALSE
    	         }
    	numstats <- 10 + length(quant)	+ IQR 
+   	cn <- "X1"
     if ( NCOL(x) < 2)  {if(is.data.frame(x)) {      #
                 if( !is.numeric(x[,1])) {warning ("You were trying to describe a non-numeric data.frame or vector which describe converted  to numeric.")
                     x[,1] <- as.numeric(as.factor(x[,]))
                     } 
-        
+              if(!is.null(colnames(x))) {cn <- colnames(x)} else {cn  <- "X1"}
+             
                x <- x[,1] }   #getting around the problem of single column data frames       
                 #do it for vectors or 
     	    len  <- 1
@@ -136,7 +138,8 @@ if(inherits(x,"formula")) {ps <- fparse(x)   #group was specified, call describe
              Iqr <- Quart[,2] -Quart[,1] 
              stats[1,11] <- Iqr
              }
-			rownames(stats) <- "X1"
+            
+			rownames(stats) <- cn
     	} else {
    nvar <- ncol(x)	
    stats = matrix(rep(NA,nvar*numstats),ncol=numstats)    #create a temporary array
@@ -224,7 +227,8 @@ if(inherits(x,"formula")) {ps <- fparse(x)   #group was specified, call describe
     if (numstats > (10+ IQR)) {if(nvar > 1 ) {answer <- data.frame(answer, stats[,(IQR+11):numstats])   #add the quantile information
                                      } else { 
 
-                                       answer <- data.frame(answer, t(stats[,(IQR+11):numstats])) }
+                                       answer <- data.frame(answer, t(stats[,(IQR+11):numstats])) 
+                                       rownames(answer) <- cn}
                         }     
                          
     
@@ -253,3 +257,4 @@ if(inherits(x,"formula")) {ps <- fparse(x)   #group was specified, call describe
     return(answer)
     }
 }
+#minor patch on 9/10/23 for case of single variables with quants
\ No newline at end of file
