@@ -1,5 +1,5 @@
 
-
+#modified 7/25/21 to report factor scores so that we can use biplot on the exensions.\
 "fa.extension" <-
   function(Roe,fo,correct=TRUE) {
  cl <- match.call()
@@ -25,12 +25,16 @@
        } 
     }
     }
- 
+ #Roe is Horn's Re    R1 is Phi  Pc is pattern of original = fl
+ # Pe = Re Pc  solve (Pc'Pc) solve Phi
  if(!omega) fe <- t( Roe) %*% fl %*% (solve(t(fl)%*% (fl)))  #should we include Phi?
-  if(!is.null(Phi)) fe <- fe %*% solve(Phi)
+  if(!is.null(Phi)) fe <- fe %*% solve(Phi)  #horn equation 26
  
- if(!correct) {#the Gorsuch case
-     d <-diag(t(fl) %*% fo$weight)
+ if(!correct) {#the Gorsuch case -- not actually-- read Gorsuch again
+
+    # d <- diag(t(fl) %*% fo$weight)  #this is probably  wrong 
+     
+     d <- sqrt(diag(t(fl) %*% fo$weight))   #a correction of sorts for reliability
      fe <- (fe * d)
  }
  colnames(fe) <- colnames(fl)
@@ -48,16 +52,21 @@ if(!is.null(Phi)) {resid <- Roe - fl %*% Phi %*% t(fe)} else {resid <- Roe - fl
 #modified 31/5/14 to allow for omega extension as well 
 #modified 04-09/16 to pass the Structure matrix as well
 #Added the cors and correct parameters to pass to fa 1/3/21
+
+
 "fa.extend" <- 
-function(r,nfactors=1,ov=NULL,ev=NULL,n.obs = NA, np.obs=NULL,correct=TRUE,rotate="oblimin",SMC=TRUE,warnings=TRUE, fm="minres",alpha=.1, omega=FALSE,cor="cor",use="pairwise",cor.correct=.5,weight=NULL, ...) {
+function(r,nfactors=1,ov=NULL,ev=NULL,n.obs = NA, np.obs=NULL,correct=TRUE,rotate="oblimin",SMC=TRUE,warnings=TRUE, fm="minres",alpha=.1, omega=FALSE,cor="cor",use="pairwise",cor.correct=.5,weight=NULL,smooth=TRUE, ...) {
  cl <- match.call()
+ if(is.numeric(ev)) ev  <- colnames(r)[ev]    #in case we are selecting variables 
+ if(is.numeric(ov)) ov  <- colnames(r)[ov]
   nv <- c(ov,ev)
  if(nrow(r) > ncol(r)){  #the case of a data matrix
      #first find the correlations
       n.obs <- nrow(r)
          np.obs.r <- pairwiseCount(r)[nv,nv]
          np.obs <- np.obs.r[ov,ov]
-       # r <- cor(r,use='pairwise') 
+         data <- r  #if we want to find factor scores
+  # r <- cor(r,use='pairwise') 
        switch(cor, 
        cor = {r <- cor(r,use=use) },   #does not include the weight option from fa 
        cov = {r <- cov(r,use=use) 
@@ -73,13 +82,15 @@ function(r,nfactors=1,ov=NULL,ev=NULL,n.obs = NA, np.obs=NULL,correct=TRUE,rotat
        )
        
  if(omega) {fo <- omega(r[ov,ov],nfactors=nfactors,rotate=rotate,SMC=SMC,warnings=warnings,fm=fm,alpha=alpha,...)} else {
-       fo <- fa(r[ov,ov],nfactors=nfactors,rotate=rotate,SMC=SMC,warnings=warnings,fm=fm,cor=cor,alpha=alpha,...)}
-         
-    } else {  #the case of a correlation matrix         
+       fo <- fa(r[ov,ov],nfactors=nfactors,rotate=rotate,SMC=SMC,warnings=warnings,fm=fm,cor=cor,alpha=alpha,smooth=smooth,...)}
+     
+           
+    } else {  #the case of a correlation matrix  
+       data <- NULL       
        R <- r[ov,ov]
        np.obs.r <- np.obs
       if(omega) {fo <- omega(R,nfactors=nfactors,n.obs=n.obs,rotate=rotate,SMC=SMC,warnings=warnings,fm=fm,cor=cor,alpha=alpha,np.obs=np.obs[ov,ov],...)} else { 
-      fo <- fa(R,nfactors=nfactors,n.obs=n.obs,rotate=rotate,SMC=SMC,warnings=warnings,fm=fm,cor=cor, correct=correct,alpha=alpha,np.obs=np.obs[ov,ov],...)}
+      fo <- fa(R,nfactors=nfactors,n.obs=n.obs,rotate=rotate,SMC=SMC,warnings=warnings,fm=fm,cor=cor, correct=correct,alpha=alpha,np.obs=np.obs[ov,ov],smooth=smooth,...)}
      }
 Roe <- r[ov,ev,drop=FALSE]
 fe <- fa.extension(Roe,fo,correct=correct)
@@ -90,7 +101,7 @@ foe <- rbind(fo$loadings,fe$loadings)
 if(omega) oblique <- rbind(fo$schmid$oblique,fe$oblique)
 
 if(is.na(n.obs) && !is.null(np.obs)) n.obs <- max(as.vector(np.obs))
-result <- factor.stats(r[nv,nv],foe,fo$Phi,n.obs,np.obs.r,alpha=alpha)
+result <- factor.stats(r[nv,nv],foe,fo$Phi,n.obs,np.obs.r,alpha=alpha,smooth=smooth,coarse=FALSE)  #this is the second call to factor.stats
 if(omega) result$schmid$sl <- foe
     result$rotation <- rotate
     result$loadings <- foe
@@ -99,6 +110,7 @@ if(omega) result$schmid$sl <- foe
     result$fm <- fm  #remember what kind of analysis we did
     
     result$fo=fo
+    if(!is.null(data)) result$scores <- factor.scores(data[,ov],fo)
     if(omega) {result$schmid$sl <- foe
               result$schmid$gloading <- fo$schmid$gloading
               result$schmid$oblique <- oblique
@@ -109,13 +121,10 @@ if(omega) result$schmid$sl <- foe
     result$Phi=fo$Phi
     result$fn="fa"
     result$Call=cl
+
 class(result) <- c("psych","extend")
 return(result)
 }
 
 
-#adapted from fa.diagram but treats the extension variables as y variables
-#draw the standard fa.diagram for the original variables and then regressions to the fe variables
-#basically for the case of extension to criterion variables with lower path strengths 
-#offers a bit more control in the e.cut and e.simple options
 
