@@ -15,8 +15,8 @@ fa = {
 	data <- as.matrix(data)
 	if(ncol(data) ==1) data <- t(data)
 	if(missing(old.data)) {data <- scale(data)} else {
-	stats <- describe(old.data)
-	data <- scale(data,center=stats$mean,scale=stats$sd)}
+	  stats <- describe(old.data)
+	   data <- scale(data,center=stats$mean,scale=stats$sd)}
 	wt <- object$weights
 	if(impute !="none") data <- impute.na(data,impute)
 	if(missing) {pred <- matrixMult.na(data,wt)} else {
@@ -60,7 +60,7 @@ setCor = {
 	data <- scale(data,center=stats$mean,scale=stats$sd)}
 	wt <- object$coefficients[vars,]  #don't use the intercept
 	if(impute !="none") data <- impute.na(data,impute)
-	if(missing) {pred <- matrixMult.na(data,wt)} else {
+	if(missing) {pred <- matrixMult.na(data,wt,scale=FALSE)} else {
 	pred <- data %*% wt}
    }
 )
@@ -70,7 +70,7 @@ return(pred)}
 
 
 #these next two do not standardize the prediction
-"predict.principal" <-
+"predict_principal" <-
 function(object,data) {
 wt <- object$weights
 data <- as.matrix(data)
@@ -78,7 +78,7 @@ pred <- data %*% wt
 return(pred)
 }
 
-"predict.fa" <-
+"predict_fa" <-
 function(object,data) {
 wt <- object$weights
 data <- as.matrix(data)
@@ -86,7 +86,7 @@ pred <- data %*% wt
 return(pred)
 }
 
-predict.setCor.best <- function(object,data,p=.01){
+predict_setCor.best <- function(object,data,p=.01){
  data <- as.matrix(data)
  vars <- rownames(object$coefficients)
  vars <- vars[ vars %in% colnames(data)]
@@ -103,11 +103,12 @@ matrixMult.na <- function(x,y,scale=TRUE) {
 nvar <- ncol(x)
 if(nvar != nrow(y) ) stop("matrices are not compatible")#matrices are not compatible
 
-if(scale) x <- scale(x) #zero center and standaridize
+if(scale) {x <- scale(x)} #zero center and standaridize
+#if(scale) {y <- scale(y)} #zero center and standaridize
 tx <- t(x) #we want to do  it on the transposed matrix
 ny <- ncol(y)
 result <- matrix(NA,nrow = nrow(x),ncol= ncol(y))
-result <- apply(y,2,function(x ) colMeans(x * tx,na.rm=TRUE))
+result <- apply(y,2,function(x ) colSums(x * tx,na.rm=TRUE))  #changed to sums rather than means  06/16/21
 return((result))
 }
 
@@ -122,7 +123,7 @@ return((result))
  }
  
  
- cor.na <- function(x,y=NULL,scale=TRUE) {
+ cor_na <- function(x,y=NULL,scale=TRUE) {
 nvar <- ncol(x)
 if(scale) {sx <- scale(x)} else {sx <- x}
 if(is.null(y)) y <- sx
