@@ -1,8 +1,9 @@
 #November 30, 2013
 #parts adapted from combn
-#modified 6/20/21 to just do the unique splits if < 10,000
+#modified 6/20/21 to just do the unique splits if < 15,000 *i.e. a 16 variable problem
+#modified 9/7/21 to handle keys as lists of variable names with negative signs
 "splitHalf"<- 
-function(r,raw=FALSE,brute=FALSE,n.sample=10000,covar=FALSE,check.keys=TRUE,key=NULL,ci=.05,use="pairwise") {
+function(r,raw=FALSE,brute=FALSE,n.sample=15000,covar=FALSE,check.keys=TRUE,key=NULL,ci=.05,use="pairwise") {
 cl <- match.call()
 
 split <- function(o,n) {
@@ -16,6 +17,7 @@ Rab <- R[1,2]/sqrt(R[1,1]*R[2,2])
 rab <- 4*R[1,2]/sum(R)
 result <- list(rab=rab,AB=AB)}
 
+#if(!is.null(key)) {r <- r[,selectFromKeys(key)]}
 v.names <- colnames(r)
 keys <- key   
 maxrb <- -9999
@@ -23,7 +25,9 @@ minrb <- 2
 n <- ncol(r)
 n2 <- trunc(n/2)
 n.obs <- nrow(r)
-if(n.obs > n) { r <- cov(r,use=use)}
+
+#if(n.obs > n) { r <- cov(r,use=use)}    # fails if n.obs < n
+if(!isCovariance(r))  { r <- cov(r,use=use)}   
  if(!covar) r <- cov2cor(r) 
  
 if(check.keys && is.null(keys)) {
@@ -32,7 +36,10 @@ if(check.keys && is.null(keys)) {
             keys <- 1- 2* (p1$loadings < 0 ) 
             }  #keys is now a vector of 1s and -1s
             
-         if(is.null(keys)) {keys <- rep(1,n)} else {  
+         if(is.null(keys)) {keys <- rep(1,n)} else {     #in case keys is a list, we need to tranform to a keys vector 
+            if(is.character(keys))  {temp <- rep(1,n)
+                  temp[which(strtrim(keys,1)=="-")] <- -1
+                  keys <- temp } 
          			keys<- as.vector(keys) 
          			if(length(keys) < n) {temp <- keys  #this is the option of keying just the reversals
          			                         keys <- rep(1,n)
@@ -43,7 +50,7 @@ if(check.keys && is.null(keys)) {
                      r <- key.d %*% r %*% key.d
                      signkey <- strtrim(keys,1)
             		 signkey[signkey=="1"] <- ""
-                     colnames(r) <- paste(colnames(r),signkey,sep="")
+                     colnames(r) <- paste(signkey,colnames(r),sep="")
 
 e <- 0
 m <- n2
@@ -73,7 +80,8 @@ brute <- TRUE
  #first do the original order
         o <- a
         sp <- split(o,n)
-        if(raw) result[1] <- sp$rab
+        if(raw) result[1] <- abs(sp$rab)
+        sp$rab <- abs(sp$rab)
         maxrb <- sp$rab
         maxAB <- sp$AB
         minrb <- sp$rab
@@ -94,8 +102,9 @@ i <- 2 #now, do the rest
              a[m - h + j] <- e + j 
             o <-  x[a]
             sp <- split(o,n)
-         if(raw) result[i] <- sp$rab
-          sumr <- sumr+ sp$rab
+         if(raw) result[i] <- abs(sp$rab )
+           sp$rab <- abs(sp$rab)  #conrolling for a rare case
+            sumr <- sumr+ sp$rab  # summing all of the split halfs to eventually report mean splithalf
           if(sp$rab > maxrb) {maxrb  <- sp$rab
                               maxAB <- sp$AB}
         if(sp$rab < minrb) {minrb <- sp$rab
@@ -123,10 +132,13 @@ for (i in 1:n.sample) {
  #now 
 if(brute) {meanr <- sumr/count } else {meanr <- sumr/n.sample }
 
+
 kd <- diag(key.d)    #reverse them so we can use the keys
-maxAB = maxAB * kd
+maxAB =maxAB * kd
 minAB = minAB * kd
 rownames(maxAB) <- rownames(minAB) <- v.names
+maxAB <- keys2list(maxAB)
+minAB <- keys2list(minAB)
 if(!anyNA(result))  {
 ci <- quantile(result,c(ci/2,.5, 1 - ci/2))} else {ci <- rep(NA,3) }
 if(raw) {
